Skip to main contentCrate deferred_map
Source - DefaultKey
- DeferredMap
- DeferredMap is a high-performance map based on slotmap
- Generation
- A generation counter that is always non-zero.
- Handle
- Handle is a one-time token for inserting values into DeferredMap
- SecondaryMap
- A secondary map that associates data with keys from a
DeferredMap. - Version
- Represents the version of a slot, combining generation and state.
- SecondaryMapBindError
- Errors returned when a
SecondaryMap cannot bind to a primary map. - SecondaryMapInsertError
- Errors returned when a
SecondaryMap rejects an insertion.
- Key